@@ -33,8 +33,6 @@ R_LIB_VERSION_HEADER(r_anal);
    bb_has_ops=1 -> 600M
    bb_has_ops=0 -> 350MB
  */
-#define R_ANAL_BB_HAS_OPS 0
-
 /* TODO: work in progress */
 #define USE_NEW_FCN_STORE 0
 
@@ -68,6 +66,9 @@ typedef struct r_anal_range_t {
 #define R_ANAL_UNMASK_TYPE(x) (x&R_ANAL_VAR_TYPE_SIZE_MASK)
 #define R_ANAL_UNMASK_SIGN(x) (((x& R_ANAL_VAR_TYPE_SIGN_MASK)>> R_ANAL_VAR_TYPE_SIGN_SHIFT)==R_ANAL_VAR_TYPE_UNSIGNED)?0:1
 
+#define R_ANAL_GET_OFFSET(x,y,z) \
+	(x && x->binb.bin && x->binb.get_offset)? \
+		x->binb.get_offset (x->binb.bin, y, z): -1
 enum {
 	R_ANAL_DATA_TYPE_NULL = 0,
 	R_ANAL_DATA_TYPE_UNKNOWN = 1,
@@ -177,17 +178,16 @@ enum {
 	R_ANAL_FQUALIFIER_VIRTUAL = 5,
 };
 
-enum {
-	R_ANAL_CC_TYPE_NONE,
-	R_ANAL_CC_TYPE_CDECL,
-	R_ANAL_CC_TYPE_STDCALL,
-	R_ANAL_CC_TYPE_FASTCALL,
-	R_ANAL_CC_TYPE_PASCAL,
-	R_ANAL_CC_TYPE_WINAPI, // Microsoft's pascal call clone
-	R_ANAL_CC_TYPE_MSFASTCALL, // microsoft fastcall
-	R_ANAL_CC_TYPE_BOFASTCALL, // borland fastcall
-	R_ANAL_CC_TYPE_WAFASTCALL, // wacom fastcall
-	R_ANAL_CC_TYPE_CLARION, // TopSpeed/Clarion/JPI
+/*--------------------Function Convnetions-----------*/
+#define	R_ANAL_CC_TYPE_CDECL 'a'
+#define	R_ANAL_CC_TYPE_STDCALL 0
+#define R_ANAL_CC_TYPE_FASTCALL 'A' // syscall
+#define	R_ANAL_CC_TYPE_PASCAL 1
+#define R_ANAL_CC_TYPE_WINAPI 2 // Microsoft's pascal call clone
+#define R_ANAL_CC_TYPE_MSFASTCALL 3 // microsoft fastcall
+#define R_ANAL_CC_TYPE_BOFASTCALL 4 // borland fastcall
+#define R_ANAL_CC_TYPE_WAFASTCALL 5 // wacom fastcall
+#define R_ANAL_CC_TYPE_CLARION 6 // TopSpeed/Clarion/JPI
 	/* Clarion:
 	 *	first four integer parameters are passed in registers:
 	 *	eax, ebx, ecx, edx. Floating point parameters are passed
@@ -198,10 +198,9 @@ enum {
 	 *	Integer values are returned in eax, pointers in edx
 	 *	and floating point types in st0.
 	 */
-	R_ANAL_CC_TYPE_SAFECALL, // Delphi and Free Pascal on Windows
-	R_ANAL_CC_TYPE_SYSV,
-	R_ANAL_CC_TYPE_THISCALL,
-};
+#define R_ANAL_CC_TYPE_SAFECALL 7 // Delphi and Free Pascal on Windows
+#define R_ANAL_CC_TYPE_SYSV 8
+#define R_ANAL_CC_TYPE_THISCALL 9
 
 #define R_ANAL_CC_ARGS 16
 
@@ -275,31 +274,40 @@ typedef struct r_anal_fcn_store_t {
 	RList *l;
 } RAnalFcnStore;
 
+/* Stores useful function metadata */
+/* TODO: Think about moving more stuff to this structure? */
+typedef struct r_anal_fcn_meta_t {
+	ut64 min;           // min address
+	ut64 max;           // max address
+	int numrefs;        // number of cross references
+	int numcallrefs;    // number of calls
+	int sgnc;           // node cardinality of the functions callgraph
+	int sgec;           // edge cardinality of the functions callgraph
+} RAnalFcnMeta;
+
 /* Store various function information,
  * variables, arguments, refs and even
  * description */
 typedef struct r_anal_type_function_t {
 	char* name;
 	char* dsc; // For producing nice listings
-	ut32 size;
+	ut32 _size;
 	int bits; // ((> bits 0) (set-bits bits))
 	short type;
 	/*item_list *rets; // Type of return value */
-	short rets;
+	char *rets;
 	short fmod; //  static, inline or volatile?
 	/* TODO: Change to RAnalCC ??? */
 	short call; // calling convention
 	char* attr; // __attribute__(()) list
 	ut64 addr;
-	int stack;
+	int stack; //stack frame size
+	int maxstack;
 	int ninstr;
 	int nargs; // Function arguments counter
 	int depth;
 	bool folded;
 	RAnalType *args; // list of arguments
-#if USE_VARSUBS
-	RAnalVarSub varsubs[R_ANAL_VARSUBS];
-#endif
 	ut8 *fingerprint; // TODO: make is fuzzy and smarter
 	RAnalDiff *diff;
 	RList *locs; // list of local variables
@@ -310,26 +318,14 @@ typedef struct r_anal_type_function_t {
 	RList *refs;
 	RList *xrefs;
 #endif
+	RAnalFcnMeta meta;
 } RAnalFunction;
 
 struct r_anal_type_t {
 	char *name;
-	ut32 size;
 	ut32 type;
-	union {
-		RAnalTypeVar *v;
-		RAnalTypePtr *p;
-		RAnalTypeArray *a;
-		RAnalTypeStruct *s;
-		RAnalTypeUnion *u;
-		RAnalTypeAlloca *al;
-		RAnalFunction *f;
-	} custom;
-	RAnalType *next;
-	RAnalType *prev;
-	RAnalType *head;
-	// Parent filename
-	char* filename;
+	ut32 size;
+	RList *content;
 };
 
 enum {
@@ -357,6 +353,7 @@ enum {
 	R_ANAL_OP_FAMILY_MMX,    /* multimedia instruction (packed data) */
 	R_ANAL_OP_FAMILY_PRIV,   /* priviledged instruction */
 	R_ANAL_OP_FAMILY_CRYPTO, /* cryptographic instructions */
+	R_ANAL_OP_FAMILY_VIRT,   /* virtualization instructions */
 	R_ANAL_OP_FAMILY_LAST
 };
 
@@ -397,10 +394,12 @@ typedef enum {
 	R_ANAL_OP_TYPE_COND  = 0x80000000, // TODO must be moved to prefix?
 	//TODO: MOVE TO PREFIX .. it is used by anal_ex.. must be updated
 	R_ANAL_OP_TYPE_REP   = 0x40000000, /* repeats next instruction N times */
+	R_ANAL_OP_TYPE_MEM   = 0x20000000, // TODO must be moved to prefix?
 	R_ANAL_OP_TYPE_NULL  = 0,
 	R_ANAL_OP_TYPE_JMP   = 1,  /* mandatory jump */
 	R_ANAL_OP_TYPE_UJMP  = 2,  /* unknown jump (register or so) */
 	R_ANAL_OP_TYPE_CJMP  = R_ANAL_OP_TYPE_COND | R_ANAL_OP_TYPE_JMP,  /* conditional jump */
+	R_ANAL_OP_TYPE_MJMP  = R_ANAL_OP_TYPE_MEM | R_ANAL_OP_TYPE_JMP,  /* conditional jump */
 	R_ANAL_OP_TYPE_UCJMP = R_ANAL_OP_TYPE_COND | R_ANAL_OP_TYPE_UJMP, /* conditional unknown jump */
 	R_ANAL_OP_TYPE_CALL  = 3,  /* call to subroutine (branch+link) */
 	R_ANAL_OP_TYPE_UCALL = 4, /* unknown call (register or so) */
@@ -459,14 +458,22 @@ typedef enum {
 
 /* TODO: what to do with signed/unsigned conditionals? */
 typedef enum {
-	R_ANAL_COND_EQ = 0,
-	R_ANAL_COND_NE,
-	R_ANAL_COND_GE,
-	R_ANAL_COND_GT,
-	R_ANAL_COND_LE,
-	R_ANAL_COND_LT,
-	R_ANAL_COND_AL,
-	R_ANAL_COND_NV,
+	R_ANAL_COND_AL = 0,        // Always executed (no condition)
+	R_ANAL_COND_EQ,            // Equal
+	R_ANAL_COND_NE,            // Not equal
+	R_ANAL_COND_GE,            // Greater or equal
+	R_ANAL_COND_GT,            // Greater than
+	R_ANAL_COND_LE,            // Less or equal
+	R_ANAL_COND_LT,            // Less than
+	R_ANAL_COND_NV,            // Never executed             must be a nop? :D
+	R_ANAL_COND_HS,            // Carry set                  >, ==, or unordered
+	R_ANAL_COND_LO,            // Carry clear                Less than
+	R_ANAL_COND_MI,            // Minus, negative            Less than
+	R_ANAL_COND_PL,            // Plus, positive or zero     >, ==, or unordered
+	R_ANAL_COND_VS,            // Overflow                   Unordered
+	R_ANAL_COND_VC,            // No overflow                Not unordered
+	R_ANAL_COND_HI,            // Unsigned higher            Greater than, or unordered
+	R_ANAL_COND_LS             // Unsigned lower or same     Less than or equal
 } _RAnalCond;
 
 typedef enum {
@@ -520,6 +527,8 @@ enum {
 	R_ANAL_STACK_INC,
 	R_ANAL_STACK_GET,
 	R_ANAL_STACK_SET,
+	R_ANAL_STACK_RESET,
+	R_ANAL_STACK_ALIGN,
 };
 
 enum {
@@ -582,6 +591,7 @@ typedef struct r_anal_options_t {
 	int noncode;
 	int nopskip; // skip nops at the beginning of functions
 	int jmptbl; // analyze jump tables
+	bool pushret; // analyze push+ret as jmp
 } RAnalOptions;
 
 typedef struct r_anal_t {
@@ -633,8 +643,6 @@ typedef struct r_anal_t {
 #if DEPRECATE
 	Sdb *sdb_args;  //
 	Sdb *sdb_vars; // globals?
-	//Sdb *sdb_locals;
-	// Sdb *sdb_ret;   // UNUSED
 #endif
 	Sdb *sdb_hints; // OK
 	Sdb *sdb_fcnsign; // OK
@@ -707,16 +715,16 @@ typedef struct r_anal_op_t {
 	int stackop;    /* operation on stack? */
 	int cond;       /* condition type */
 	int size;       /* size in bytes of opcode */
-	int nopcode;    /* number of bytes representing the opcode (not the arguments) */
+	int nopcode;    /* number of bytes representing the opcode (not the arguments) TODO: find better name */
 	int cycles;	/* cpu-cycles taken by instruction */
 	int failcycles;	/* conditional cpu-cycles */
 	int family;     /* family of opcode */
-	int eob;        /* end of block (boolean) */
+	bool eob;        /* end of block (boolean) */
 	/* Run N instructions before executing the current one */
 	int delay;      /* delay N slots (mips, ..)*/
 	ut64 jump;      /* true jmp */
 	ut64 fail;      /* false jmp */
-	ut32 selector;  /* segment selector */
+	//ut32 selector;  /* segment selector */
 	st64 ptr;       /* reference to memory */ /* XXX signed? */
 	ut64 val;       /* reference to value */ /* XXX signed? */
 	int ptrsize;    /* f.ex: zero extends for 8, 16 or 32 bits only */
@@ -725,8 +733,9 @@ typedef struct r_anal_op_t {
 	RAnalVar *var;  /* local var/arg used by this instruction */
 	RAnalValue *src[3];
 	RAnalValue *dst;
-	struct r_anal_op_t *next; // XXX deprecate
+	struct r_anal_op_t *next; // TODO deprecate
 	RStrBuf esil;
+	const char *reg; /* destination register */
 	RAnalSwitchOp *switch_op;
 } RAnalOp;
 
@@ -753,18 +762,14 @@ typedef struct r_anal_bb_t {
 	char *label;
 	ut8 *fingerprint;
 	RAnalDiff *diff;
-#if R_ANAL_BB_HAS_OPS
-	RList *ops;
-#endif
 	RAnalCond *cond;
 	RAnalSwitchOp *switch_op;
 	// offsets of instructions in this block
 	ut16 *op_pos;
 	// size of the op_pos array
-	int n_op_pos;
+	int op_pos_size;
 	ut8 *op_bytes;
 	ut8 op_sz;
-	ut64 eflags;
 	/* deprecate ??? where is this used? */
 	/* iirc only java. we must use r_anal_bb_from_offset(); instead */
 	struct r_anal_bb_t *head;
@@ -1020,6 +1025,7 @@ typedef int (*RAnalBbCallback)(RAnal *a, RAnalBlock *bb, ut64 addr, const ut8 *d
 typedef int (*RAnalFnCallback)(RAnal *a, RAnalFunction *fcn, ut64 addr, const ut8 *data, int len, int reftype);
 
 typedef int (*RAnalRegProfCallback)(RAnal *a);
+typedef char*(*RAnalRegProfGetCallback)(RAnal *a);
 typedef int (*RAnalFPBBCallback)(RAnal *a, RAnalBlock *bb);
 typedef int (*RAnalFPFcnCallback)(RAnal *a, RAnalFunction *fcn);
 typedef int (*RAnalDiffBBCallback)(RAnal *anal, RAnalFunction *fcn, RAnalFunction *fcn2);
@@ -1097,6 +1103,7 @@ typedef struct r_anal_plugin_t {
 	RAnalCmdExt cmd_ext;
 
 	RAnalRegProfCallback set_reg_profile;
+	RAnalRegProfGetCallback get_reg_profile;
 	RAnalFPBBCallback fingerprint_bb;
 	RAnalFPFcnCallback fingerprint_fcn;
 	RAnalDiffBBCallback diff_bb;
@@ -1123,6 +1130,7 @@ R_API RAnalFunction *r_listrange_find_in_range(RListRange* s, ut64 addr);
 R_API RAnalFunction *r_listrange_find_root(RListRange* s, ut64 addr);
 /* --------- */ /* REFACTOR */ /* ---------- */
 /* type.c */
+R_API int r_anal_type_get_size (RAnal *anal, const char *type);
 R_API RAnalType *r_anal_type_new(void);
 R_API void r_anal_type_add(RAnal *l, RAnalType *t);
 R_API void r_anal_type_del(RAnal *l, const char *name);
@@ -1133,28 +1141,32 @@ R_API RAnalType *r_anal_str_to_type(RAnal *a, const char* s);
 R_API char *r_anal_type_to_str(RAnal *a, const char *name);
 R_API const char *r_anal_optype_to_string(int t);
 R_API const char *r_anal_op_family_to_string (int n);
+R_API int r_anal_op_family_from_string(const char *f);
 R_API RAnalType *r_anal_type_free(RAnalType *t);
 R_API RAnalType *r_anal_type_loadfile(RAnal *a, const char *path);
 R_API void r_anal_type_define (RAnal *anal, const char *key, const char *value);
 R_API void r_anal_type_header (RAnal *anal, const char *hdr);
 
 R_API int r_anal_type_link (RAnal *anal, const char *val, ut64 addr);
+R_API int r_anal_type_unlink(RAnal *anal, ut64 addr);
 R_API char *r_anal_type_format (RAnal *anal, const char *t);
 R_API int r_anal_type_set(RAnal *anal, ut64 at, const char *field, ut64 val);
 
 /* anal.c */
+R_API void r_anal_type_init(RAnal *anal);
 R_API RAnal *r_anal_new(void);
 R_API int r_anal_purge (RAnal *anal);
 R_API RAnal *r_anal_free(RAnal *r);
 R_API void r_anal_set_user_ptr(RAnal *anal, void *user);
 R_API void r_anal_plugin_free (RAnalPlugin *p);
 R_API int r_anal_add(RAnal *anal, RAnalPlugin *foo);
-R_API int r_anal_list(RAnal *anal);
+R_API void r_anal_list(RAnal *anal);
 R_API int r_anal_archinfo(RAnal *anal, int query);
-R_API int r_anal_use(RAnal *anal, const char *name);
-R_API int r_anal_set_reg_profile(RAnal *anal);
-R_API int r_anal_set_bits(RAnal *anal, int bits);
-R_API int r_anal_set_os(RAnal *anal, const char *os);
+R_API bool r_anal_use(RAnal *anal, const char *name);
+R_API bool r_anal_set_reg_profile(RAnal *anal);
+R_API char *r_anal_get_reg_profile(RAnal *anal);
+R_API bool r_anal_set_bits(RAnal *anal, int bits);
+R_API bool r_anal_set_os(RAnal *anal, const char *os);
 R_API void r_anal_set_cpu(RAnal *anal, const char *cpu);
 R_API int r_anal_set_big_endian(RAnal *anal, int boolean);
 R_API char *r_anal_strmask (RAnal *anal, const char *data);
@@ -1182,7 +1194,7 @@ R_API ut64 r_anal_bb_opaddr_at(RAnalBlock *bb, ut64 addr);
 R_API const char *r_anal_stackop_tostring (int s);
 R_API RAnalOp *r_anal_op_new(void);
 R_API void r_anal_op_free(void *op);
-R_API void r_anal_op_fini(RAnalOp *op);
+R_API bool r_anal_op_fini(RAnalOp *op);
 R_API bool r_anal_op_is_eob (RAnalOp *op);
 R_API RList *r_anal_op_list_new(void);
 R_API int r_anal_op(RAnal *anal, RAnalOp *op, ut64 addr,
@@ -1231,10 +1243,12 @@ R_API RAnalFunction *r_anal_fcn_new(void);
 R_API int r_anal_fcn_is_in_offset (RAnalFunction *fcn, ut64 addr);
 R_API RAnalFunction *r_anal_get_fcn_at(RAnal *anal, ut64 addr, int type);
 R_API RAnalFunction *r_anal_get_fcn_in(RAnal *anal, ut64 addr, int type);
+R_API RAnalFunction *r_anal_get_fcn_in_bounds(RAnal *anal, ut64 addr, int type);
 R_API RAnalFunction *r_anal_fcn_find_name(RAnal *anal, const char *name);
 R_API RList *r_anal_fcn_list_new(void);
 R_API int r_anal_fcn_insert(RAnal *anal, RAnalFunction *fcn);
 R_API void r_anal_fcn_free(void *fcn);
+R_API void fill_args (RAnal *anal, RAnalFunction *fcn, RAnalOp *op);
 R_API int r_anal_fcn(RAnal *anal, RAnalFunction *fcn, ut64 addr,
 		ut8 *buf, ut64 len, int reftype);
 R_API int r_anal_fcn_add(RAnal *anal, ut64 addr, ut64 size,
@@ -1244,7 +1258,7 @@ R_API int r_anal_fcn_del_locs(RAnal *anal, ut64 addr);
 R_API int r_anal_fcn_add_bb(RAnal *anal, RAnalFunction *fcn,
 		ut64 addr, ut64 size,
 		ut64 jump, ut64 fail, int type, RAnalDiff *diff);
-R_API int check_fcn(RAnal *anal, ut8 *buf, ut16 bufsz, ut64 addr, ut64 low, ut64 high);
+R_API bool r_anal_check_fcn(RAnal *anal, ut8 *buf, ut16 bufsz, ut64 addr, ut64 low, ut64 high);
 
 /* locals */
 #if 0
@@ -1274,7 +1288,9 @@ R_API int r_anal_var_count(RAnal *a, RAnalFunction *fcn, int kind);
 
 /* vars // globals. not here  */
 
-
+R_API ut32 r_anal_fcn_size(const RAnalFunction *fcn);
+R_API void r_anal_fcn_set_size(RAnalFunction *fcn, ut32 size);
+R_API ut32 r_anal_fcn_realsize(const RAnalFunction *fcn);
 R_API int r_anal_fcn_cc(RAnalFunction *fcn);
 R_API int r_anal_fcn_split_bb(RAnal *anal, RAnalFunction *fcn, RAnalBlock *bb, ut64 addr);
 R_API int r_anal_fcn_bb_overlaps(RAnalFunction *fcn, RAnalBlock *bb);
@@ -1294,6 +1310,7 @@ R_API int r_anal_fcn_resize (RAnalFunction *fcn, int newsize);
 #define r_anal_fcn_get_vars(x) x->vars
 #define r_anal_fcn_get_bbs(x) x->bbs
 #else
+R_API int r_anal_xrefs_count(RAnal *anal);
 R_API const char *r_anal_xrefs_type_tostring (char type);
 R_API RList *r_anal_xrefs_get (RAnal *anal, ut64 to);
 R_API RList *r_anal_xrefs_get_from (RAnal *anal, ut64 from);
@@ -1303,7 +1320,7 @@ R_API RList* r_anal_fcn_get_xrefs (RAnalFunction *anal);
 R_API int r_anal_xrefs_from (RAnal *anal, RList *list, const char *kind, const RAnalRefType type, ut64 addr);
 R_API int r_anal_xrefs_set (RAnal *anal, const RAnalRefType type, ut64 from, ut64 to);
 R_API int r_anal_xrefs_deln (RAnal *anal, const RAnalRefType type, ut64 from, ut64 to);
-R_API void r_anal_xrefs_save(RAnal *anal, const char *prjfile);
+R_API bool r_anal_xrefs_save(RAnal *anal, const char *prjfile);
 R_API RList* r_anal_fcn_get_vars (RAnalFunction *anal);
 R_API RList* r_anal_fcn_get_bbs (RAnalFunction *anal);
 R_API RList* r_anal_get_fcns (RAnal *anal);
@@ -1343,12 +1360,13 @@ R_API const char *r_anal_var_scope_to_str(RAnal *anal, int scope);
 R_API int r_anal_var_access_add(RAnal *anal, RAnalVar *var, ut64 from, int set);
 R_API int r_anal_var_access_del(RAnal *anal, RAnalVar *var, ut64 from);
 R_API RAnalVarAccess *r_anal_var_access_get(RAnal *anal, RAnalVar *var, ut64 from);
+R_API RAnalVar *r_anal_var_get_byname (RAnal *anal, RAnalFunction *fcn, char kind, const char* name);
 
 /* project */
-R_API int r_anal_project_load(RAnal *anal, const char *prjfile);
-R_API int r_anal_project_save(RAnal *anal, const char *prjfile);
-R_API int r_anal_xrefs_load(RAnal *anal, const char *prjfile);
-R_API int r_anal_xrefs_init (RAnal *anal);
+R_API bool r_anal_project_load(RAnal *anal, const char *prjfile);
+R_API bool r_anal_project_save(RAnal *anal, const char *prjfile);
+R_API bool r_anal_xrefs_load(RAnal *anal, const char *prjfile);
+R_API bool r_anal_xrefs_init (RAnal *anal);
 
 #define R_ANAL_THRESHOLDFCN 0.7F
 #define R_ANAL_THRESHOLDBB 0.7F
@@ -1381,6 +1399,7 @@ R_API void r_anal_cond_free (RAnalCond *c);
 R_API char *r_anal_cond_to_string(RAnalCond *cond);
 R_API int r_anal_cond_eval (RAnal *anal, RAnalCond *cond);
 R_API RAnalCond *r_anal_cond_new_from_string(const char *str);
+R_API const char *r_anal_cond_tostring(int cc);
 
 /* reflines.c */
 R_API RList* /*<RAnalRefline>*/ r_anal_reflines_get(RAnal *anal,
@@ -1429,8 +1448,12 @@ R_API int r_meta_space_count_for(RAnal *a, int ctx);
 R_API RList *r_meta_enumerate(RAnal *a, int type);
 R_API int r_meta_count(RAnal *m, int type, ut64 from, ut64 to);
 R_API char *r_meta_get_string(RAnal *m, int type, ut64 addr);
+R_API char *r_meta_get_var_comment (RAnal *a, int type, ut64 idx, ut64 addr);
 R_API int r_meta_set_string(RAnal *m, int type, ut64 addr, const char *s);
+R_API int r_meta_set_var_comment (RAnal *a, int type, ut64 idx, ut64 addr, const char *s);
 R_API int r_meta_del(RAnal *m, int type, ut64 from, ut64 size, const char *str);
+R_API int r_meta_var_comment_del(RAnal *a, int type, ut64 idx, ut64 addr);
+R_API RAnalVar *r_anal_var_get_byname (RAnal *anal, RAnalFunction *fcn, char kind, const char* name);
 R_API int r_meta_add(RAnal *m, int type, ut64 from, ut64 size, const char *str);
 R_API RAnalMetaItem *r_meta_find(RAnal *m, ut64 off, int type, int where);
 R_API int r_meta_cleanup(RAnal *m, ut64 from, ut64 to);
@@ -1560,6 +1583,8 @@ extern RAnalPlugin r_anal_plugin_riscv;
 extern RAnalPlugin r_anal_plugin_vax;
 extern RAnalPlugin r_anal_plugin_i4004;
 extern RAnalPlugin r_anal_plugin_xtensa;
+extern RAnalPlugin r_anal_plugin_pic18c;
+extern RAnalPlugin r_anal_plugin_rsp;
 #ifdef __cplusplus
 }
 #endif
